[![CI](https://github.com/DiamondLightSource/dls-backup-bl/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/dls-backup-bl/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/DiamondLightSource/dls-backup-bl/branch/main/graph/badge.svg)](https://codecov.io/gh/DiamondLightSource/dls-backup-bl)
[![PyPI](https://img.shields.io/pypi/v/dls-backup-bl.svg)](https://pypi.org/project/dls-backup-bl)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

# dls_backup_bl

A backup tool for beamlines for pmacs, terminal servers, zebras

Source          | <https://github.com/DiamondLightSource/dls-backup-bl>
:---:           | :---:
PyPI            | `pip install dls-backup-bl`
Docker          | `docker run ghcr.io/diamondlightsource/dls-backup-bl:latest`
Releases        | <https://github.com/DiamondLightSource/dls-backup-bl/releases>
